<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>MX Asystent sieci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="76"/>
        <source>IP address</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Hardware detected</source>
        <translation>Wykryto sprzęt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <location filename="../mainwindow.ui" line="389"/>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Re-scan</source>
        <translation>Skanuj ponownie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Active interface</source>
        <translation>Aktywny interfejs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>WiFi status</source>
        <translation>Status WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Odblokowuje wszystkie programowo/sprzętowo zablokowane urządzenia bezprzewodowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Unblock WiFi Devices</source>
        <translation>Odblokuj urządzenia WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>Linux drivers</source>
        <translation>Sterowniki Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Associated Linux drivers</source>
        <translation>Powiązane sterowniki systemu Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Load Driver</source>
        <translation>Załaduj sterownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Unload Driver</source>
        <translation>Odinstaluj sterownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Block Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Windows drivers</source>
        <translation>Sterowniki Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="434"/>
        <source>Available Windows drivers</source>
        <translation>Dostępne sterowniki dla systemu Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Remove Driver</source>
        <translation>Usuń sterownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>Add Driver</source>
        <translation>Dodaj sterownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>About NDISwrapper</source>
        <translation>Informacje o NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Install NDISwrapper</source>
        <translation>Zainstaluj NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Aby korzystać ze sterowników Windows, musisz najpierw zainstalować NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="559"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Odinstaluj NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Net diagnostics</source>
        <translation>Diagnostyka sieci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <location filename="../mainwindow.ui" line="726"/>
        <source>Target URL:</source>
        <translation>Docelowy adres URL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="619"/>
        <source>Packets</source>
        <translation>Pakiety</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <location filename="../mainwindow.ui" line="781"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="692"/>
        <location filename="../mainwindow.ui" line="812"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Hops</source>
        <translation>Skoki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="891"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="959"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>IP address from router:</source>
        <translation>Adres IP z routera:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>External IP address:</source>
        <translation>Zewnętrzny adres IP:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>Copy &amp;All</source>
        <translation>Copy &amp;All</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <location filename="../mainwindow.cpp" line="215"/>
        <location filename="../mainwindow.cpp" line="229"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute not installed</source>
        <translation>Traceroute nie jest zainstalowany</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Traceroute nie jest zainstalowany, czy chcesz go teraz zainstalować?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Traceroute nie został zainstalowany</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Nie można zainstalować Traceroute. Może to oznaczać, że korzystasz z LiveCD lub nie możesz połączyć się z repozytorium oprogramowania.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Traceroute nie jest zainstalowany i nie można wykryć połączenia z Internetem, więc nie można go zainstalować</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>No destination host</source>
        <translation>Brak docelowego hosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Please fill in the destination host field</source>
        <translation>Proszę wypełnić pole hosta docelowego</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Loaded Drivers</source>
        <translation>Załadowane sterowniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>Unloaded Drivers</source>
        <translation>Niezaładowane sterowniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Blocked Drivers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Blocked Broadcom Drivers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="894"/>
        <source>enabled</source>
        <translation>włączony</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>disabled</source>
        <translation>wyłączony</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="900"/>
        <source>WiFi hardware switch is off</source>
        <translation>Przełącznik sprzętowy WiFi jest wyłączony</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Zlokalizuj sterownik Windows, który chcesz dodać</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Plik informacji dla instalacji systemu Windows (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>*.sys file not found</source>
        <translation>nie znaleziono pliku *.sys</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="939"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Pliki *.sys muszą znajdować się w tej samej lokalizacji, co plik *.inf. Nie można znaleźć %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>sys file reference not found</source>
        <translation>nie znaleziono odwołania do pliku sys</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="948"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Plik sys dla danego sterownika nie może zostać określony po analizie pliku inf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="967"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Usunięto sterownik Ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>%1 Help</source>
        <translation>%1 Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1013"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation>Program do konfigurowania sieci i rozwiązywania problemów dla systemu MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1016"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Prawa autorskie © MEPIS LLC i MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1017"/>
        <source>%1 License</source>
        <translation>%1 Licencja</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>You must run this program as root.</source>
        <translation>Musisz uruchomić ten program jako administrator. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Ndiswrapper is not installed</source>
        <translation>NDISwrapper nie jest zainstalowany</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>driver installed</source>
        <translation>sterownik zainstalowany</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source> and in use by </source>
        <translation>i w użyciu przez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>. Alternate driver: </source>
        <translation>. Alternatywny sterownik:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="613"/>
        <source>Driver removed from blocklist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="614"/>
        <source>Driver removed from blocklist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Module blocked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>Installation successful</source>
        <translation>Instalacja zakończyła się sukcesem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="789"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Wykryto błąd, nie można skompilować sterownika NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Wykryto błąd, nie można zainstalować NDISwrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Wystąpił błąd podczas usuwania NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="855"/>
        <source>Unblock Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Block Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="995"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Nie można odblokować urządzeń.
Urządzenia Wi-Fi mogą być już odblokowane.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>WiFi devices unlocked.</source>
        <translation>Urządzenia WiFi odblokowane.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1040"/>
        <location filename="../mainwindow.cpp" line="1041"/>
        <source>Driver loaded successfully</source>
        <translation>Sterownik został pomyślnie załadowany</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1056"/>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>Driver unloaded successfully</source>
        <translation>Sterownik został pomyślnie odinstalowany</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Could not load </source>
        <translation>Nie można załadować</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <source>Could not unload </source>
        <translation>Nie można odinstalować</translation>
    </message>
</context>
</TS>
